@@ -11,10 +11,7 @@ use vars    qw[$VERSION @ISA @EXPORT];
 
 use Package::Constants;
 
-### for the version
-require CPANPLUS::Internals;
-
-$VERSION = "0.9906";
+$VERSION = "0.9914";
 @ISA        = qw[Exporter];
 @EXPORT     = Package::Constants->list( __PACKAGE__ );
 
